@@ -2,12 +2,14 @@ package cmd
 
 import (
 	"fmt"
+	"os"
 	"runtime/debug"
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/color"
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/view"
+	"github.com/mattn/go-colorable"
 	"github.com/rs/zerolog"
 	"github.com/rs/zerolog/log"
 	"github.com/spf13/cobra"
@@ -33,6 +35,8 @@ var (
 		Long:  longAppDesc,
 		Run:   run,
 	}
+
+	out = colorable.NewColorableStdout()
 )
 
 func init() {
@@ -59,6 +63,17 @@ func run(cmd *cobra.Command, args []string) {
 		}
 	}()
 
+	config.EnsurePath(*k9sFlags.LogFile, config.DefaultDirMod)
+	mod := os.O_CREATE | os.O_APPEND | os.O_WRONLY
+	file, err := os.OpenFile(*k9sFlags.LogFile, mod, config.DefaultFileMod)
+	defer func() {
+		_ = file.Close()
+	}()
+	if err != nil {
+		panic(err)
+	}
+	log.Logger = log.Output(zerolog.ConsoleWriter{Out: file})
+
 	zerolog.SetGlobalLevel(parseLevel(*k9sFlags.LogLevel))
 	app := view.NewApp(loadConfiguration())
 	if err := app.Init(version, *k9sFlags.RefreshRate); err != nil {
@@ -147,6 +162,12 @@ func initK9sFlags() {
 		config.DefaultLogLevel,
 		"Specify a log level (info, warn, debug, error, fatal, panic, trace)",
 	)
+	rootCmd.Flags().StringVarP(
+		k9sFlags.LogFile,
+		"logFile", "",
+		config.DefaultLogFile,
+		"Specify the log file",
+	)
 	rootCmd.Flags().BoolVar(
 		k9sFlags.Headless,
 		"headless",
